#
# spec file for package charliecloud
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           charliecloud
Version:        0.22
Release:        lp152.2.6.1
Summary:        User-defined software stacks (UDSS) for HPC centers
License:        Apache-2.0
Group:          Productivity/Clustering/Computing
URL:            https://hpc.github.io/charliecloud/
Source0:        https://github.com/hpc/charliecloud/releases/download/v%{version}/%{name}-%{version}.tar.gz
Patch0:         Replace-hardcode-path.patch
BuildRequires:  python3-base
# Recommend for ch-grow
# used to build images
Requires:       fakeroot
Recommends:     docker
Recommends:     buildah >= 1.11.2
Recommends:     python3-requests >= 2.6.0
Recommends:     squashfs >= 4.2
%if !(0%{?sle_version} <= 120400 && 0%{?is_backports})
Recommends:     python3-lark-parser >= 0.7.1
%endif
# Build the documentation
%if !(0%{?sle_version} <= 120400 && 0%{?is_backports})
BuildRequires:  python3-Sphinx
BuildRequires:  python3-sphinx_rtd_theme
BuildRequires:  rsync
%endif

%description
Charliecloud provides user-defined software stacks (UDSS)
for high-performance computing (HPC) centers. This "bring your own
software stack" functionality addresses needs such as: software
dependencies that are numerous, complex, unusual, differently configured,
or simply newer/older than what the center provides; build-time
requirements unavailable within the center, such as relatively
unfettered internet access; validated software stacks and configuration
to meet the standards of a particular field of inquiry; portability of
environments between resources, including workstations and other test
and development system not managed by the center; consistent
environments, even archivally so, that can be easily, reliabily, and
verifiably reproduced in the future; and/or usability and
comprehensibility.

%package doc
Summary:        Documentation files for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
Charliecloud provides user-defined software stacks (UDSS)
for high-performance computing (HPC) centers.
This package provides documentation files for Charliecloud.

%package examples
Summary:        Example files for %{name}
Group:          Documentation/Other
BuildArch:      noarch

%description examples
Charliecloud provides user-defined software stacks (UDSS)
for high-performance computing (HPC) centers.
This package provides example files for Charliecloud.

%prep
%setup -q
%patch0 -p 1

%build
%configure --disable-test
make %{?_smp_mflags}

%install
%make_install

# Documentation won't build on SLE-12
%if !(0%{?sle_version} <= 120400 && 0%{?is_backports})
mv %{buildroot}%{_datadir}/doc/charliecloud/html .
%endif

# Fix shebangs
sed -E -i "s|^#!/usr/bin/env python3|#!/usr/bin/python3|" %{buildroot}%{_bindir}/ch-*

## Remove built examples
rm -rf  %{buildroot}%{_datadir}/doc/charliecloud/examples
## Remove Makefile scripts from the examples package
rm -rf examples/Makefile*
# Fix shebangs in examples
sed -E -i "s|^#!/usr/bin/env python3|#!/usr/bin/python3|" examples/chtest/*

## Remove test related files
rm -rf %{buildroot}%{_bindir}/ch-test %{buildroot}%{_libdir}/charliecloud/contributors.bash

%files
%license LICENSE
%doc README.rst
%{_bindir}/*
%dir %{_libdir}/charliecloud/
%{_libdir}/charliecloud/*

%if !(0%{?sle_version} <= 120400 && 0%{?is_backports})
%{_mandir}/man1/*
%{_mandir}/man7/*

%files doc
%license LICENSE
%doc html
%endif

%files examples
%license LICENSE
%doc examples

%changelog
* Mon Feb 22 2021 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to version 0.22.
  - “ch-image” can now push images to a registry, with the “push” subcommand
  - As a reminder, “ch-grow” has been renamed to “ch-image”.
    The old name still works but will be removed in 0.23.
  - ch-image: new subcommand “delete”
  - ch-image pull:
  * now keeps some metadata from pulled image
  * now works with public images in nVidia NGC registry
  * setuid/setgid bits in pulled image now cleared
  * performance improvements for images with many whiteouts
  - ch-image build:
  * environment variables now kept from base image
  * SHELL instruction now supported
  - several scripts now work correctly if image name contains slash
  - “sudo make install” now works correctly with restrictive umasks
  - miscellaneous bug fixes and improvements
* Mon Dec 21 2020 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to version 0.21.
  - renamed the internal builder ch-grow to ch-image to reflect
    its broader functionality. ch-grow still works but will be
    deprecated in 0.23
  - ch-image unprivileged build workarounds using fakeroot
    now default to off and must be requested with --force;
    the option --no-fakeroot has been removed. ch-image will
    by default print a warning if it thinks --force might fix
    a build failure.
  - ch-image pull now works with registries that use HTTP basic auth
    and with images that use manifest schema version 1.
  - ch-image build has a new option --bind to bind-mount directories
    during build and COPY: improve symlink and directory handling
  - miscellaneous bug fixes and improvements
  - Full changelog at https://groups.io/g/charliecloud/message/108
- Update patch
  * Replace-hardcode-path.patch
* Wed Oct 21 2020 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to version 0.20.
  - improvement for unprivileged image build using fakeroot
    This feature can be turned off with “ch-grow build --no-fakeroot”
    Further details are in the ch-grow man page
  - miscellaneous bug fixes and improvements
  - Full changelot at https://groups.io/g/charliecloud/message/107
- Add requirements on fakeroot
* Tue Sep 22 2020 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to version 0.19. Two particularly notable changes:
  - ch-grow now supports multi-stage build (#768), which as always
    is fully unprivileged. This represents a big step forward in
    functionality.
  - ch-grow now has subcommands; what used to be plain ch-grow
    is now ch-grow build, and ch-tug has become ch-grow pull.
  - miscellaneous bug fixes and improvements
  - Full changelog at https://groups.io/g/charliecloud/message/106
- Update patch
  * Replace-hardcode-path.patch
* Fri Aug 21 2020 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to version 0.18
  - Fixes an important symlink handling bug in ch-tug and ch-grow.
    Prior to version 0.18, if a pulled image contained a symlink in one
    layer and then a regular file at the same path in a subsequent layer,
    the *target* of the symlink would be overwritten even if it was
    not within the image; i.e., unpacking inappropriately followed
    the symlink. This allows a crafted image to overwrite any file
    writeable by the invoking user.
    Because Charliecloud is unprivileged, other files on the system,
    e.g. system files, are unaffected.
  - ch-grow: --version and --help work w/o dependencies installed
    new switch --list to list images
    now gives diagnostics for syntax errors and unsupported instructions
    WORKDIR now supports relative paths (#786)
    no longer crashes if input doesn’t end in newline (#474)
  - miscellaneous bug fixes and improvements
  - Full changelogs at https://groups.io/g/charliecloud/message/104
    and https://groups.io/g/charliecloud/message/105
- Replace python2-base with python3-base.
- Update recommends used by ch-grow/ch-build
- Readd patch for hardcoded paths:
  * Replace-hardcode-path.patch
* Fri Jun 26 2020 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to version 0.16
  - ch-grow and ch-tug: updates to work with external repositories
  - ch-grow: COPY semantics now match Docker
  - miscellaneous bug fixes and improvements
  - Full changelog at https://groups.io/g/charliecloud/message/103
* Wed Apr 15 2020 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to version 0.15
  - shell and Python libraries moved from libexec to lib
  - Full changelog at https://groups.io/g/charliecloud/message/102
- Remove patch, paths are not longer hardcoded:
  * 0001-Replace-hardcoded-libexec.patch
* Wed Mar  4 2020 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to version 0.14
  - the build system was rewritten and the layout of the source code
    and installed files were changed significantly
  - new binary ch-tug, to pull images from a remote repository
  - miscellaneous bug fixes and improvements
- Patch the usage of /usr/libexec to use /usr/lib because upstream
  have harcoded the first path in its code.
  * 0001-Replace-hardcoded-libexec.patch
* Tue Jan 21 2020 Ondřej Súkup <mimi.vx@gmail.com>
- Switch to python3-Sphinx for building the documentation
* Thu Nov  7 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to version 0.12:
  - ch-docker2squash renamed to dh-builder2squash
  - new binary ch-test, not shipped in the package for now
  - Full changelog at https://groups.io/g/charliecloud/message/98
- Add recommends on buildah
* Mon Sep 23 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to version 0.11:
  - ch-run: /etc/resolv.conf on the host is now optional
  - ch-grow: support ARG instruction
  - build now does not infinite loop if no Python installed
  - miscellaneous bug fixes, and documentation and test suite
    improvements
  - Full changelog at https://groups.io/g/charliecloud/message/97
* Fri Aug  2 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to version 0.10:
  - New builder ch-grow
  - ch-build includes option --builder
  - ch-docker2tar renamed to ch-builder2tar
  - new quashFS wrapper scripts: ch-docker2squash, ch-docker2squash,
    ch-tar2squash, ch-mount and ch-umount
  - new namespace tester ch-checkns
  - Full changelog at https://groups.io/g/charliecloud/message/96
- examples/syscalls is not built anymore, drop make clean.
- Fix shebangs of new scripts to avoid dependency on /usr/bin/env
* Thu May 23 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Update Source0 to use the tarball created by upstream and not the
  automatic one created by GitHub.
* Thu May 23 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to version 0.9.10:
  - Documentation and examples: misc improvements.
  - Full changelog at https://groups.io/g/charliecloud/message/88
- Update Source0 to allow source verification
- Install prebuilt manpages in Backports:SLE-12. We don't build the
  documentation in this release because the build requirements don't
  exist.
* Fri May 10 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to version 0.9.9:
  - Bugfixes and documentation improvements.
  - Full changelog at https://groups.io/g/charliecloud/message/87
- Re-add make clean clean that was actually needed.
* Thu Apr 11 2019 Martin Pluskal <mpluskal@suse.com>
- Build using distribution-wide CFLAGS
- Be more explicit with python dependency
- Drop useless make clean call
* Tue Apr  9 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Do not build documentation in Backports:SLE-12 because the build
  requirements don't exist.
* Wed Mar 27 2019 Jan Engelhardt <jengelh@inai.de>
- Add missing Group: tags.
* Tue Mar 26 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Add Recommends on docker. While Docker is not needed to run
  charliecloud it can be used to build images
* Tue Mar 12 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Initial release, version 0.9.8.
